/*
 * crlf2lf -- simple CR code cut filter.
 *
 *  Copyright (C) 1995 Generation System Software Labo Distribution.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <stdio.h>
#include <errno.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include "getopt.h"

/*
 * setvbuffer is alias function for misc.
 */
#ifdef __human68k__
#define setvbuffer(fp, buf, size) setvbuf(fp, buf, _IOFBF, size)
#else /* BSD */
#define setvbuffer(fp, buf, size) setbuffer(fp, buf, size)
#endif

#define IOBUF_SIZE 16384

char stdibuf[IOBUF_SIZE];
char stdobuf[IOBUF_SIZE];
const char *version_string = "GSSLD crlf2lf version 1.0.0";
char *program_name;
int verbose_opt = 0;

static struct option const longopts[] =
{
  {"help", no_argument, NULL, 'h'},
  {"verbose", no_argument, NULL, 'v'},
  {"version", no_argument, NULL, 'V'},
  {NULL, 0, NULL, 0}
};

int main (int, char **);
void crlf_lf (FILE *);
void usage (void);

int
main (argc, argv)
     int argc;
     char **argv;
{

  int lf_crlf = 0;
  int ch, rval;
  FILE *fd;

  char *fn;
  program_name = argv[0];

  setvbuffer (stdout, stdobuf, IOBUF_SIZE);

  while ((ch = getopt_long (argc, argv, "hvV", longopts, (int *) 0)) != EOF)
    switch (ch)
      {
      case 'h':
	usage ();
	break;
      case 'v':
	verbose_opt = 1;
	break;
      case 'V':
	printf ("%s\n", version_string);
	exit (0);
	break;
      default:
	usage ();
	break;
      }

  argc -= optind;
  argv += optind;
  fd = stdin;
  fn = NULL;
  rval = 0;
  do
    {
      if (*argv)
	{
	  fn = *argv++;
	  if ((fd = fopen (fn, "r")) == NULL)
	    {
	      (void) fprintf (stderr, "%s: %s: %s\n",
			      program_name, fn, strerror (errno));
	      rval = 1;
	      continue;
	    }
	}
      (void) setvbuffer (fd, stdibuf, IOBUF_SIZE);
      crlf_lf (fd);
      fclose(fd);
    }
  while (*argv);
  exit (rval);
}

void
crlf_lf (fp)
     FILE *fp;
{
  int c;
  while ((c = getc (fp)) != EOF)
    {
      if (c != 0x0d)
	(void) putchar (c);
    }
}

void
usage (void)
{
  (void) fprintf (stderr, "usage: %s [-hv] [--help,verbose,version] [file ...]\n"
		  ,program_name);
  exit (1);
}
